@@ -4,9 +4,9 @@ immutable collections. There is a naive check that eliminates some of the most c
 mutable collections in the instance check. However, a guaranteed check is probably
 impossible to implement, so some amount of developer discipline is required.
 
-Sized types are created by subclassing ``PhantomSized`` and providing a predicate that
-will be called with the size of the tested collection. For instance, ``NonEmpty`` is
-implemented using ``len=numeric.greater(0)``.
+Sized types are created by subclassing :py:class:`PhantomSized` and providing a
+predicate that will be called with the size of the tested collection. For instance,
+:py:class:`NonEmpty` is implemented using ``len=numeric.greater(0)``.
 
 This made-up type would describe sized collections with between 5 and 10 ints:
 
@@ -18,9 +18,6 @@ This made-up type would describe sized collections with between 5 and 10 ints:
 from typing import Any
 from typing import Generic
 from typing import Iterable
-from typing import MutableMapping
-from typing import MutableSequence
-from typing import MutableSet
 from typing import Sized
 from typing import TypeVar
 
@@ -31,11 +28,10 @@ from numerary.types import RealLike
 # to documentation of _ProtocolMeta.
 # https://github.com/python/cpython/commit/74d7f76e2c953fbfdb7ce01b7319d91d471cc5ef
 try:
-    from typing_extensions import _ProtocolMeta  # type: ignore[attr-defined]
+    from typing_extensions import _ProtocolMeta
 except ImportError:
-    from typing import _ProtocolMeta  # type: ignore[attr-defined]
+    from typing import _ProtocolMeta  # type: ignore[attr-defined,no-redef]
 
-from typing_extensions import Final
 from typing_extensions import Protocol
 from typing_extensions import runtime_checkable
 
@@ -47,6 +43,7 @@ from .predicates import collection
 from .predicates import generic
 from .predicates import numeric
 from .schema import Schema
+from .utils import is_not_mutable_instance
 
 __all__ = (
     "SizedIterable",
@@ -56,7 +53,6 @@ __all__ = (
 )
 
 
-mutable: Final = (MutableSequence, MutableSet, MutableMapping)
 T = TypeVar("T", bound=object, covariant=True)
 
 
@@ -65,9 +61,7 @@ class SizedIterable(Sized, Iterable[T], Protocol[T]):
     """Intersection of :py:class:`typing.Sized` and :py:class:`typing.Iterable`."""
 
 
-# This raises a mypy error because disallow_subclassing_any is enabled and _ProtocolMeta
-# isn't publicly typed.
-class SizedIterablePhantomMeta(PhantomMeta, _ProtocolMeta):  # type: ignore[misc]
+class SizedIterablePhantomMeta(PhantomMeta, _ProtocolMeta):
     ...
 
 
@@ -84,7 +78,7 @@ class PhantomSized(
     def __init_subclass__(cls, len: Predicate[RealLike], **kwargs: Any) -> None:
         super().__init_subclass__(
             predicate=boolean.both(
-                boolean.negate(generic.of_type(mutable)),
+                is_not_mutable_instance,
                 collection.count(len),
             ),
             **kwargs,
